@@ -78,6 +78,10 @@ function do_search (event, tab) {
       }
 
       // delegate to any [device|search] specific JS code
+      $('div.content > div.tab-content table.nd_floatinghead').floatThead({
+        scrollingTop: 40
+        ,useAbsolutePositioning: false
+      });
       inner_view_processing(tab);
     }
   );
@@ -216,11 +220,21 @@ $(document).ready(function() {
     $('.nd_sidebar').toggle(250);
     $('#nd_sidebar-toggle-img-out').toggle();
     $('.content').css('margin-right', '10px');
+    $('div.content > div.tab-content table.nd_floatinghead').floatThead('destroy');
+    $('div.content > div.tab-content table.nd_floatinghead').floatThead({
+      scrollingTop: 40
+      ,useAbsolutePositioning: false
+    });
     sidebar_hidden = 1;
   });
   $('#nd_sidebar-toggle-img-out').click(function() {
     $('#nd_sidebar-toggle-img-out').toggle();
     $('.content').css('margin-right', '215px');
+    $('div.content > div.tab-content table.nd_floatinghead').floatThead('destroy');
+    $('div.content > div.tab-content table.nd_floatinghead').floatThead({
+      scrollingTop: 40
+      ,useAbsolutePositioning: false
+    });
     $('.nd_sidebar').toggle(250);
     if (! $('.nd_sidebar').hasClass('nd_sidebar-pinned')) {
         $(window).scrollTop(0);
